#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SIGNNZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SIGNNZ_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/signnz.hpp>

#endif
